pub struct AsyncSinkConfig {
pub max_events: usize,
pub max_bytes: usize,
}Expand description
Count and retained-byte ceilings for one asynchronous sink.
Fields
max_events: usizeMaximum events retained across the queue and active delivery.
max_bytes: usizeMaximum estimated event bytes retained across queue and active delivery.